@@ -1,8 +1,5 @@
 package Slovo::Plugin::MojoDBx;
 use Mojo::Base 'Mojolicious::Plugin', -signatures;
-use feature qw(lexical_subs unicode_strings);
-## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
-no warnings "experimental::lexical_subs";
 
 sub register ($self, $app, $conf = {}) {
   $conf = $self->_check_config($app, $conf);
@@ -113,7 +110,7 @@ sub _check_config ($self, $app, $conf) {
 
 =head1 NAME
 
-Slovo::Plugin::MojoDBx - load and use Mojo::Pg/mysql/SQLite
+Slovo::Plugin::MojoDBx - load and use Mojo::Pg|mysql|SQLite
 
 =head1 SYNOPSIS
 
